@@ -162,7 +162,7 @@ class Recording(ABC):
         """Returns a string with information about the Recording"""
         pass
     
-    def add_sync_line(self, line, processor_id, stream_name=0, main=False):
+    def add_sync_line(self, line, processor_id, stream_name=None, main=False):
         """Specifies an event channel to use for timestamp synchronization. Each 
         sync line in a recording should receive its input from the same 
         physical digital input line.
@@ -175,10 +175,10 @@ class Recording(ABC):
         channel : int
             event channel number
         processor_id : int
-            ID for the processor receiving sync events
-        stream_index : int
-            index of the stream receiving sync events
-            default = 0
+            ID for the processor receiving sync events (eg 101)
+        stream_name : str
+            name of the stream receiving sync events (eg 'Probe-A-AP')
+            default = None
         main : bool
             if True, this stream's timestamps will be treated as the 
             main clock
@@ -273,8 +273,7 @@ class Recording(ABC):
                         ((continuous.sample_numbers - sync['start']) * sync['scaling'] \
                             + sync['offset']) 
                             
-                    if self.format != 'nwb': # already scaled to seconds
-                        continuous.global_timestamps = continuous.global_timestamps / sync['sample_rate']
+                    continuous.global_timestamps = continuous.global_timestamps / sync['sample_rate'] / sync['scaling']
                             
             event_inds = self.events[(self.events.processor_id == sync['processor_id']) & 
                    (self.events.stream_name == sync['stream_name'])].index.values
@@ -283,8 +282,7 @@ class Recording(ABC):
                                   * sync['scaling'] \
                                    + sync['offset']
                                    
-            if self.format != 'nwb': #already scaled to seconds
-                global_timestamps = global_timestamps / sync['sample_rate']
+            global_timestamps = global_timestamps / sync['sample_rate']
             
             for ind, ts in zip(event_inds, global_timestamps):
                 self.events.at[ind, 'global_timestamp'] = ts
@@ -296,4 +294,4 @@ class Recording(ABC):
         
     
         
-    
\ No newline at end of file
+    
